@@ -8,6 +8,7 @@ use base 'Protocol::WebSocket::Handshake';
 require Carp;
 
 use Protocol::WebSocket::URL;
+use Protocol::WebSocket::Frame;
 
 sub new {
     my $self = shift->SUPER::new(@_);
@@ -61,6 +62,12 @@ sub parse {
 sub is_done   { shift->res->is_done }
 sub to_string { shift->req->to_string }
 
+sub build_frame {
+    my $self = shift;
+
+    return Protocol::WebSocket::Frame->new(masked => 1, version => $self->version, @_);
+}
+
 sub _build_url { Protocol::WebSocket::URL->new }
 
 sub _set_url {
@@ -74,7 +81,9 @@ sub _set_url {
     my $req = $self->req;
 
     my $host = $url->host;
-    $host .= ':' . $url->port if defined $url->port;
+    $host .= ':' . $url->port
+      if defined $url->port
+      && ($url->secure ? $url->port ne '443' : $url->port ne '80');
     $req->host($host);
 
     $req->resource_name($url->resource_name);
